Learn R Programming

Rankcluster (version 0.93.1)

distSpearman: Spearman distance between two ranks

Description

The Spearman distance is the square of Euclidean distance between two rank vector.

Usage

distSpearman(x, y)

Arguments

x, y
two ranks of size m.

Value

an integer, the Spearman distance between x and y.

Examples

Run this code
x=1:5
y=c(2,3,1,4,5)
distSpearman(x,y)

Run the code above in your browser using DataLab