rankclust(data, m = ncol(data), K = 1, criterion = "bic", Qsem = 100, Bsem = 20, RjSE = m * (m - 1)/2, RjM = m * (m - 1)/2, Ql = 500, Bl = 100, maxTry = 3, run = 1, detail = FALSE)Output-class and Rankclust-class).For example :
res=rankclust(data,K=1:2,m=m)You can access the result by res[number of groups]@slotName where slotName is an element of the class Output.
- missing positions are replaced by 0
- tied are replaced by the lowest position they share"
The ranking representation r=(r_1,...,r_m) contains the ranks assigned to the objects, and means that the ith object is in r_ith position.
The ordering representation o=(o_1,...,o_m) means that object o_i is in the ith position.
Let us consider the following example to illustrate both notations: a judge, which has to rank three holidays destinations according to its preferences, O1 = Countryside, O2 =Mountain and O3 = Sea, ranks first Sea, second Countryside, and last Mountain. The ordering result of the judge is o = (3, 1, 2) whereas the ranking result is r = (2, 3, 1).
[2] J.Jacques and C.Biernacki (2012), Model-based clustering for multivariate partial ranking data, Inria Research Report n 8113.
Output-class and Rankclust-class for available output.
data(big4)
result=rankclust(big4$data,K=2,m=big4$m,Ql=200,Bl=100,maxTry=2)
Run the code above in your browser using DataLab